#line 2 "scan.c"

#line 4 "scan.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap() 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 68
#define YY_END_OF_BUFFER 69
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[391] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   69,   67,   55,   55,   67,    5,
       56,   67,   53,   67,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   68,   68,   68,   68,   57,   57,   58,   62,
       62,   61,   61,   61,   55,    0,   54,    5,    5,    6,
       53,    0,   64,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   42,   54,
       54,   54,   54,    0,    0,    0,    0,    0,   58,    0,

        0,    6,    6,    0,    0,   64,   64,   54,    9,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   20,   54,
       54,   54,   54,   54,   54,   54,   54,   27,   54,   54,
       54,   54,   33,   54,   54,   54,   54,   54,   54,   39,
       54,   54,   54,   54,   54,   54,   54,   54,   65,    0,
        0,    0,   63,   59,    0,    6,    0,   54,   54,   54,
       54,   54,   16,   54,   54,   54,   54,   54,   54,   22,
       54,   54,   54,   25,   54,   28,   30,   31,   32,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   65,   65,   60,    6,    0,   54,

       54,   54,   54,   54,   54,   54,   54,   54,   54,   21,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   40,   41,   54,   54,   54,   54,   54,
       48,    6,    0,   54,   54,   54,   54,   54,   15,   54,
        2,   18,   54,   54,   23,   54,   24,   54,   54,   54,
       35,   54,   37,   54,   54,   52,   54,   54,   54,   45,
       46,   47,    6,    0,    8,   10,   12,   13,   14,   54,
        2,   54,   54,    1,   26,   54,   54,   36,   54,   54,
       54,   54,   54,   54,    6,    0,   11,   54,   17,   54,
       54,    1,   54,   54,   54,   54,   54,   54,   54,   44,

        6,    0,   54,   54,   54,   29,   54,   54,   54,   54,
       54,   54,    6,    0,   54,   54,   54,   34,   54,   54,
       54,   54,   54,    6,    0,   54,   19,   54,   54,   54,
       54,   54,   43,    6,    0,   54,   54,   54,   54,   54,
        3,    6,    7,   54,   54,   54,   54,    4,    6,    7,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   50,   54,   54,   54,   54,
       54,   54,   54,   54,   49,   54,   54,   51,   38,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    7,    1,    1,    8,    1,
        1,    1,    1,    1,    9,    1,    1,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,    1,   11,   12,
        1,   13,    1,   14,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
        1,   41,    1,    1,   42,    1,   43,   44,   45,   46,

       47,   48,   49,   50,   51,   24,   52,   53,   54,   55,
       56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
       66,   67,    1,    1,    1,    1,    1,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,

       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24
    } ;

static yyconst flex_int32_t yy_meta[68] =
    {   0,
        1,    2,    3,    2,    4,    1,    5,    1,    1,    5,
        1,    1,    6,    1,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        1,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7
    } ;

static yyconst flex_int16_t yy_base[409] =
    {   0,
        0,    0,  794,  793,   67,  108,   80,   81,   84,   87,
       90,   91,   94,   95,  803,  938,   98,  101,  797,  797,
      938,  789,  756,  752,   95,    0,  113,  110,   75,  108,
      109,   95,  117,  128,  110,  116,  127,  136,  153,  122,
      158,  154,  938,    0,  747,  184,  938,  938,  189,  938,
      938,  938,  938,    0,  196,  707,  704,  663,    0,  203,
      563,  550,    0,    0,  193,  172,  161,  160,  183,  168,
      194,  171,  184,  190,  190,  195,  215,  203,  188,  201,
      205,  208,  202,  222,  229,  237,  223,  228,    0,  250,
      246,  256,  255,  399,  339,  301,  277,  311,  314,  174,

      284,  284,  293,  273,  272,  262,    0,  230,    0,  272,
      282,  274,  281,  271,  285,  297,  302,  289,    0,  295,
      302,  302,  301,  305,  307,  303,  313,    0,  317,  312,
      301,  307,    0,  325,  328,  319,  327,  317,  322,  324,
      330,  337,  338,  341,  332,  338,  341,  345,  381,  210,
      222,  395,  375,  938,  181,  377,  363,  349,  368,  379,
      367,  387,    0,  389,  379,  374,  388,  381,  381,    0,
      384,  382,  386,    0,  397,  391,    0,    0,    0,  402,
      398,  403,  410,  410,  408,  417,  402,  418,  409,  429,
      416,  418,  428,  437,  468,  938,  938,  455,  435,  422,

      428,  448,  448,  445,  442,  453,  459,  463,  457,    0,
      461,  467,  469,  456,  466,  463,  464,  479,  482,  467,
      474,  475,  479,  139,    0,  492,  494,  494,  489,  485,
        0,  138,  120,  502,  503,  504,  493,  512,    0,  500,
      536,    0,  519,  502,    0,  523,    0,  525,  531,  515,
        0,  538,    0,  537,  528,    0,  542,  544,  530,    0,
        0,    0,  544,  532,    0,  533,    0,    0,    0,  549,
      576,  537,  554,  597,    0,  567,  563,    0,  569,  105,
      544,  561,  561,  583,  602,  589,    0,  576,    0,  586,
      594,  621,  592,  585,  582,  586,  603,  598,  598,    0,

      604,  595,  613,  602,  606,    0,  608,  614,  622,  621,
      624,  617,  647,  628,  635,  627,  641,    0,  628,  634,
      642,  643,  640,  671,  645,  651,    0,  662,  645,  657,
      648,  657,    0,  682,  652,  664,  670,  677,  673,  678,
        0,  719,  727,  671,  666,  681,  687,    0,  733,  736,
      693,  698,  684,  718,  102,  709,  725,  713,  719,  732,
       84,  727,  731,  724,  725,  726,  736,  728,  739,  734,
      737,  725,  740,   64,  742,    0,  741,  737,  742,  748,
      744,  757,  755,  760,    0,  773,  776,    0,    0,  938,
      823,  830,  837,  844,  851,  858,  865,  869,  872,  879,

      886,  892,  899,  906,  913,  920,  923,  930
    } ;

static yyconst flex_int16_t yy_def[409] =
    {   0,
      390,    1,  391,  391,  392,  392,  393,  393,  391,  391,
      394,  394,  395,  395,  390,  390,  390,  390,  396,  397,
      390,  390,  390,  398,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  390,  400,  401,  402,  390,  390,  390,  390,
      390,  390,  390,  403,  390,  396,  390,  397,  404,  405,
      390,  406,  407,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  400,  401,  390,  408,  402,  390,  390,

      396,  405,  405,  390,  406,  390,  407,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  390,  401,
      408,  408,  408,  390,  390,  405,  390,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  390,  390,  390,  405,  390,  399,

      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  405,  390,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  405,  390,  399,  399,  399,  399,  399,  399,
      390,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  405,  390,  399,  399,  399,  399,
      399,  390,  399,  399,  399,  399,  399,  399,  399,  399,

      405,  390,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  405,  390,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  405,  390,  399,  399,  399,  399,  399,
      399,  399,  399,  405,  390,  399,  399,  399,  399,  399,
      399,  405,  390,  399,  399,  399,  399,  399,  405,  390,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,    0,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,

      390,  390,  390,  390,  390,  390,  390,  390
    } ;

static yyconst flex_int16_t yy_nxt[1006] =
    {   0,
       16,   17,   18,   17,   19,   20,   16,   21,   22,   23,
       16,   16,   16,   24,   25,   26,   27,   28,   29,   30,
       26,   26,   31,   26,   26,   32,   33,   34,   35,   36,
       26,   37,   38,   39,   40,   41,   42,   26,   26,   26,
       16,   26,   25,   26,   27,   28,   29,   30,   26,   26,
       31,   26,   32,   33,   34,   35,   36,   26,   37,   38,
       39,   40,   41,   42,   26,   26,   26,   43,   43,   43,
       43,   45,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   48,   48,   48,   48,   49,   49,   49,   49,   49,
       49,   51,   51,   51,   51,   53,   53,   53,   53,   55,

       55,   55,   55,   55,   55,  378,   73,   43,   43,   43,
       43,   43,   45,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   65,   78,   70,  365,   66,   67,   71,   76,
       74,   79,   72,   73,   54,   54,   77,   82,   68,   75,
      390,   69,   80,  359,   83,   85,  296,   84,   43,   65,
       78,   91,   70,   66,   86,   67,   71,   76,   74,   79,
       72,  264,   81,   77,   82,   68,   75,   88,   69,   87,
       80,   83,   92,   85,   84,   93,  154,  155,   91,  263,
      257,   89,   86,  197,   90,   97,   97,   97,  110,   81,
       99,   99,   99,  111,  112,   88,   87,   55,   55,   55,

       92,  115,  119,   93,  103,  104,  103,  108,   89,  113,
      109,   90,  114,  116,   96,  120,  110,  121,  122,  117,
      111,  112,  123,  127,  390,  128,  118,  129,  115,  119,
      130,  124,  153,  131,  132,  108,  113,  141,  109,  114,
      133,  116,  120,  142,  121,  122,  117,  125,  126,  123,
      134,  127,  128,  118,  129,  158,  135,  130,  136,  124,
      131,  132,  137,  145,  143,  141,   62,  138,  133,  139,
      140,  142,  146,  148,  125,  126,  106,  134,  152,   97,
      152,  147,  158,  135,  144,  136,  390,  153,   57,  137,
      157,  145,  143,  159,  138,  390,  139,  140,  160,  164,

      146,  148,   97,   97,   97,  150,  161,  162,  147,  163,
      156,  144,   97,   97,   97,   99,   99,   99,  157,  165,
      166,  159,  167,  168,  169,  173,  160,  164,  170,  171,
      172,  174,  175,  161,  162,  176,  163,  177,  156,  178,
      179,  180,  181,   96,  182,  183,  191,  165,  166,  167,
      168,  184,  169,  173,  185,  170,  171,  172,  174,  186,
      175,  187,  188,  176,  177,  189,  178,  179,  190,  180,
      181,  182,  192,  183,  191,  193,  194,  390,  184,  390,
      199,  185,  195,  195,  195,  153,  186,  200,  187,  188,
      201,  196,  189,  202,  198,  190,  152,   97,  152,  192,

      203,  204,  193,  194,  206,  153,  207,  208,  199,  205,
      209,  149,  210,  211,  200,  212,  213,  214,  201,  215,
      217,  202,  198,  216,  218,  219,  220,  203,  221,  204,
      222,  223,  206,  207,  208,  224,  225,  205,  209,  210,
      211,  226,  212,  213,  214,  227,  230,  215,  217,  228,
      216,  218,  229,  219,  220,  231,  221,  390,  222,  223,
      233,  234,  224,  235,  225,  236,  237,  240,  226,  195,
      195,  195,  238,  227,  230,  239,  228,  241,  196,  229,
      232,  242,  244,  231,  243,  245,  246,  233,  234,  247,
      235,  248,  249,  236,  237,  240,  250,  251,  252,  238,

      253,  254,  239,  255,  256,  241,  258,  232,  259,  242,
      244,  243,  260,  245,  246,  261,  247,  262,  248,  249,
      265,  266,  267,  250,  268,  251,  252,  253,  254,  269,
      255,  256,  270,  272,  258,  273,  259,  271,  271,  271,
      260,  274,  261,  275,  262,  276,  390,  277,  265,  266,
      267,  268,  278,  279,  106,  280,  281,  269,  282,  270,
      283,  272,  273,  284,  286,  287,  288,  289,  291,  274,
      290,  275,   61,  276,  277,  297,  285,  271,  271,  271,
      278,  279,  280,  293,  281,  294,  282,  295,  283,  298,
      284,  286,  287,  288,  299,  289,  291,  290,  292,  292,

      292,  300,  297,  285,  390,  302,  390,  303,  304,  305,
      306,  293,  307,  294,  308,  295,  298,  309,  301,  310,
      312,  299,  292,  292,  292,  311,  314,  315,  318,  300,
      316,  317,  319,  302,  303,  313,  304,  305,  306,  307,
      320,  308,  321,  322,  309,  323,  301,  310,  312,  390,
      325,  326,  311,  314,  327,  315,  318,  316,  317,  328,
      319,  329,  313,  330,  331,  332,   59,  333,  320,  324,
      321,  322,  323,  390,  335,  336,  337,  341,  325,  326,
      338,  327,  339,  340,  390,  343,  344,  328,  329,  345,
      330,  346,  331,  332,  333,  347,  348,  324,  351,  352,

      334,  335,  336,  354,  337,  341,  353,  338,  101,  339,
      340,   57,  343,  355,  344,  342,  356,  345,  357,  346,
      349,  350,  349,  347,  348,  351,  352,  334,  350,  350,
      350,  354,  358,  353,  349,  350,  349,  350,  350,  350,
      360,  355,  342,  361,  356,  357,  362,  363,  364,  366,
      367,   96,  368,  369,  370,  371,   62,  372,  373,  377,
      358,  374,  375,  376,  379,   61,  380,  360,  381,  382,
      383,  361,  384,  362,  363,  385,  364,  366,  367,  368,
      369,  370,  386,  371,  372,  387,  373,  377,  374,  375,
      376,  388,  379,  380,  389,  381,  382,   60,  383,  384,

       59,   57,  390,  385,   44,   44,  390,  390,  390,  386,
      390,  390,  387,  390,  390,  390,  390,  390,  390,  388,
      390,  390,  389,   43,   43,   43,   43,   43,   43,   43,
       46,   46,   46,   46,   46,   46,   46,   47,   47,   47,
       47,   47,   47,   47,   50,   50,   50,   50,   50,   50,
       50,   52,   52,   52,   52,   52,   52,   52,   56,   56,
       56,   56,   56,   56,   56,   58,   58,  390,   58,   58,
       58,   58,   63,  390,  390,   63,   64,  390,   64,   94,
       94,   94,   94,   94,  390,   94,   95,   95,   95,   95,
       95,   95,   95,   98,   98,  390,   98,  390,   98,  100,

      100,  390,  100,  100,  100,  100,   59,   59,  390,   59,
       59,   59,   59,  102,  102,  102,  102,  102,  102,  102,
      105,  105,  105,  105,  105,  105,  105,  107,  390,  107,
      151,  151,  151,  151,  151,  151,  151,   15,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,

      390,  390,  390,  390,  390
    } ;

static yyconst flex_int16_t yy_chk[1006] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    7,    8,    7,    8,    9,    9,    9,   10,   10,
       10,   11,   12,   11,   12,   13,   14,   13,   14,   17,

       17,   17,   18,   18,   18,  374,   29,    5,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,   25,   32,   28,  361,   25,   27,   28,   31,
       30,   33,   28,   29,   13,   14,   31,   35,   27,   30,
      232,   27,   34,  355,   36,   37,  280,   36,    6,   25,
       32,   40,   28,   25,   38,   27,   28,   31,   30,   33,
       28,  233,   34,   31,   35,   27,   30,   39,   27,   38,
       34,   36,   41,   37,   36,   42,  100,  100,   40,  232,
      224,   39,   38,  155,   39,   46,   46,   46,   66,   34,
       49,   49,   49,   67,   68,   39,   38,   55,   55,   55,

       41,   70,   72,   42,   60,   60,   60,   65,   39,   69,
       65,   39,   69,   71,  150,   73,   66,   74,   75,   71,
       67,   68,   76,   78,  151,   79,   71,   80,   70,   72,
       81,   77,  151,   82,   83,   65,   69,   87,   65,   69,
       84,   71,   73,   88,   74,   75,   71,   77,   77,   76,
       84,   78,   79,   71,   80,  108,   85,   81,   85,   77,
       82,   83,   86,   91,   90,   87,  106,   86,   84,   86,
       86,   88,   92,   93,   77,   77,  105,   84,   97,   97,
       97,   92,  108,   85,   90,   85,  102,   97,  101,   86,
      104,   91,   90,  110,   86,  103,   86,   86,  111,  115,

       92,   93,   96,   96,   96,   96,  112,  113,   92,  114,
      103,   90,   98,   98,   98,   99,   99,   99,  104,  116,
      117,  110,  118,  120,  121,  125,  111,  115,  122,  123,
      124,  126,  127,  112,  113,  129,  114,  130,  103,  131,
      132,  134,  135,   95,  136,  137,  145,  116,  117,  118,
      120,  138,  121,  125,  139,  122,  123,  124,  126,  140,
      127,  141,  142,  129,  130,  143,  131,  132,  144,  134,
      135,  136,  146,  137,  145,  147,  148,  153,  138,  156,
      157,  139,  149,  149,  149,  153,  140,  158,  141,  142,
      159,  149,  143,  160,  156,  144,  152,  152,  152,  146,

      161,  162,  147,  148,  164,  152,  165,  166,  157,  162,
      167,   94,  168,  169,  158,  171,  172,  173,  159,  175,
      180,  160,  156,  176,  181,  182,  183,  161,  184,  162,
      185,  186,  164,  165,  166,  187,  188,  162,  167,  168,
      169,  189,  171,  172,  173,  190,  193,  175,  180,  191,
      176,  181,  192,  182,  183,  194,  184,  198,  185,  186,
      199,  200,  187,  201,  188,  202,  203,  206,  189,  195,
      195,  195,  204,  190,  193,  205,  191,  207,  195,  192,
      198,  208,  211,  194,  209,  212,  213,  199,  200,  214,
      201,  215,  216,  202,  203,  206,  217,  218,  219,  204,

      220,  221,  205,  222,  223,  207,  226,  198,  227,  208,
      211,  209,  228,  212,  213,  229,  214,  230,  215,  216,
      234,  235,  236,  217,  237,  218,  219,  220,  221,  238,
      222,  223,  240,  243,  226,  244,  227,  241,  241,  241,
      228,  246,  229,  248,  230,  249,  263,  250,  234,  235,
      236,  237,  252,  254,   62,  255,  257,  238,  257,  240,
      258,  243,  244,  259,  264,  266,  266,  270,  273,  246,
      272,  248,   61,  249,  250,  281,  263,  271,  271,  271,
      252,  254,  255,  276,  257,  277,  257,  279,  258,  282,
      259,  264,  266,  266,  283,  270,  273,  272,  274,  274,

      274,  284,  281,  263,  285,  286,  301,  288,  290,  291,
      293,  276,  294,  277,  295,  279,  282,  296,  285,  297,
      299,  283,  292,  292,  292,  298,  302,  303,  307,  284,
      304,  305,  308,  286,  288,  301,  290,  291,  293,  294,
      309,  295,  310,  311,  296,  312,  285,  297,  299,  313,
      314,  315,  298,  302,  316,  303,  307,  304,  305,  317,
      308,  319,  301,  320,  321,  322,   58,  323,  309,  313,
      310,  311,  312,  324,  325,  326,  328,  332,  314,  315,
      329,  316,  330,  331,  334,  335,  336,  317,  319,  337,
      320,  338,  321,  322,  323,  339,  340,  313,  344,  345,

      324,  325,  326,  347,  328,  332,  346,  329,   57,  330,
      331,   56,  335,  351,  336,  334,  352,  337,  353,  338,
      342,  342,  342,  339,  340,  344,  345,  324,  343,  343,
      343,  347,  354,  346,  349,  349,  349,  350,  350,  350,
      356,  351,  334,  357,  352,  353,  358,  359,  360,  362,
      363,   45,  364,  365,  366,  367,   24,  368,  369,  373,
      354,  370,  371,  372,  375,   23,  377,  356,  378,  379,
      380,  357,  381,  358,  359,  382,  360,  362,  363,  364,
      365,  366,  383,  367,  368,  384,  369,  373,  370,  371,
      372,  386,  375,  377,  387,  378,  379,   22,  380,  381,

       20,   19,   15,  382,    4,    3,    0,    0,    0,  383,
        0,    0,  384,    0,    0,    0,    0,    0,    0,  386,
        0,    0,  387,  391,  391,  391,  391,  391,  391,  391,
      392,  392,  392,  392,  392,  392,  392,  393,  393,  393,
      393,  393,  393,  393,  394,  394,  394,  394,  394,  394,
      394,  395,  395,  395,  395,  395,  395,  395,  396,  396,
      396,  396,  396,  396,  396,  397,  397,    0,  397,  397,
      397,  397,  398,    0,    0,  398,  399,    0,  399,  400,
      400,  400,  400,  400,    0,  400,  401,  401,  401,  401,
      401,  401,  401,  402,  402,    0,  402,    0,  402,  403,

      403,    0,  403,  403,  403,  403,  404,  404,    0,  404,
      404,  404,  404,  405,  405,  405,  405,  405,  405,  405,
      406,  406,  406,  406,  406,  406,  406,  407,    0,  407,
      408,  408,  408,  408,  408,  408,  408,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,  390,  390,  390,  390,

      390,  390,  390,  390,  390
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[69] =
    {   0,
1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 0, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scan.l"
#line 2 "scan.l"
/*-------------------------------------------------------------------------
 * scan.l
 *
 *	Flex keyword and token scanner for slony_logshipper
 *
 *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 *	Author: Jan Wieck, Afilias USA INC.
 *
 *	
 *-------------------------------------------------------------------------
 */

/*
 * Structure used to implement the input buffer stack.
 */
struct __yy_buffer
{
	YY_BUFFER_STATE	     buffer;		/* lexer buffer to restore on pop	*/
	long		         lineno;		/* line number to restore on pop	*/
	char               * fileName;		/* file name to restore on pop		*/
	FILE			   * yyin;			/* yyin to restore on pop			*/
	struct __yy_buffer * prev;			/* pointer to previous stack frame	*/
} * yy_buffer = NULL;

/*
 * Structure to hold defined symbols
 */
typedef struct _symbol
{
    char           * name;				/* Name of symbol with % prepended	*/
	char           * value;				/* Value of symbol					*/
	struct _symbol * next;				/* Pointer to next symbol			*/
} symbol;

/*
 * A buffer to send large items like literals in pieces to the parser.
 */
char yychunk[YY_BUF_SIZE / 2];

/*
 * Local data
 */
static symbol * symbols;				/* Head of list of symbols			*/

static char  *getSymbol(const char * name);	/* Return a symbol's value		*/
static void   addSymbol(char * str);	/* Add a new symbol					*/
static void   freeSymbols(void);		/* Free all symbols                 */
static void   pushBuffer(char *context);/* Push lexer buffer onto the stack	*/
static void   popBuffer( void );		/* Pop previous lexer buffer		*/

extern char * current_file;
#line 57 "scan.l"
#include "config.h"
#include "../slonik/types.h"
#include "libpq-fe.h"
#include "slony_logshipper.h"
#include "y.tab.h"




#line 907 "scan.c"

#define INITIAL 0
#define incl 1
#define define 2
#define IN_STRING 3
#define COPYSTART 4
#define COPY 5
#define COPYLS 6

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 88 "scan.l"


#line 1130 "scan.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 391 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 938 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 90 "scan.l"
{ BEGIN(incl);				}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 91 "scan.l"
{ BEGIN(define);			}
	YY_BREAK

/* ----------
 * Keywords
 * ----------
 */

case 3:
YY_RULE_SETUP
#line 99 "scan.l"
{ return K_START_CONFIG;	}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 100 "scan.l"
{ return K_START_ARCHIVE;	}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 101 "scan.l"
{ return K_CONF_COMMENT;	}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 102 "scan.l"
{ return K_ARCHIVE_COMMENT;	}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 103 "scan.l"
{ return K_EXEC_DDL;		}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 105 "scan.l"
{ return K_ANALYZE;			}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 106 "scan.l"
{ return K_AND;				}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 107 "scan.l"
{ return K_ARCHIVE;			}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 108 "scan.l"
{ return K_ARCHIVES;		}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 109 "scan.l"
{ return K_CASCADE;			}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 110 "scan.l"
{ return K_CLUSTER;			}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 111 "scan.l"
{ return K_COMMAND;			}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 112 "scan.l"
{ return K_COMMIT;			}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 113 "scan.l"
{ return K_COPY;			}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 114 "scan.l"
{ return K_DATABASE;		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 115 "scan.l"
{ return K_DELETE;			}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 116 "scan.l"
{ return K_DESTINATION;		}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 117 "scan.l"
{ return K_DIR;				}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 118 "scan.l"
{ return K_ERROR;			}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 119 "scan.l"
{ return K_FROM;			}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 120 "scan.l"
{ return K_IGNORE;			}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 121 "scan.l"
{ return K_INSERT;			}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 122 "scan.l"
{ return K_INTO;			}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 123 "scan.l"
{ return K_LOGFILE;			}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 124 "scan.l"
{ return K_MAX;				}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 125 "scan.l"
{ return K_NAME;			}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 126 "scan.l"
{ return K_NAMESPACE;		}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 127 "scan.l"
{ return K_NULL;			}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 128 "scan.l"
{ return K_ONLY;			}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 129 "scan.l"
{ return K_POST;			}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 130 "scan.l"
{ return K_PRE;				}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 131 "scan.l"
{ return K_PROCESSING;		}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 132 "scan.l"
{ return K_RENAME;			}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 133 "scan.l"
{ return K_REPLICA;			}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 134 "scan.l"
{ return K_SELECT;			}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 135 "scan.l"
{ return K_SESSION_ROLE;	}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 136 "scan.l"
{ return K_SET;				}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 137 "scan.l"
{ return K_START;			}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 138 "scan.l"
{ return K_TABLE;			}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 139 "scan.l"
{ return K_TO;				}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 140 "scan.l"
{ return K_TRANSACTION;		}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 141 "scan.l"
{ return K_TRUNCATE;		}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 142 "scan.l"
{ return K_UPDATE;			}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 143 "scan.l"
{ return K_VACUUM;			}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 144 "scan.l"
{ return K_VALUES;			}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 145 "scan.l"
{ return K_WHERE;			}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 147 "scan.l"
{ return T_TRACKING_FUNCTION; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 148 "scan.l"
{ return T_FINISH_FUNCTION;	}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 149 "scan.l"
{ return T_SEQSETVAL_FUNCTION;	}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 150 "scan.l"
{ return T_PGSETVAL_FUNCTION;	}
	YY_BREAK

/* ----------
 * Generic "things"
 * ----------
 */

case 53:
YY_RULE_SETUP
#line 158 "scan.l"
{ return T_NUMBER;			}
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 159 "scan.l"
{ return T_IDENT;			}
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
#line 161 "scan.l"
;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 163 "scan.l"
{
					char	   *cp = yychunk;
					size_t		   len = 0;
					int			c;

					BEGIN(IN_STRING);
					while(len < sizeof(yychunk) - 1)
					{
						c = input();
						if (c == EOF)
						{
							errlog(LOG_ERROR, "%s: EOF inside literal\n",
									current_file);
							BEGIN(INITIAL);
							break;
						}
						if (c == '\\')
						{
							c = input();
							if (c == EOF)
							{
								errlog(LOG_ERROR, "%s: EOF inside literal\n",
										current_file);
								BEGIN(INITIAL);
								break;
							}
							*cp++ = c;
							*cp++ = c;
							len+=2;
							continue;
						}
						if (c == '\'')
						{
							c = input();
							if (c == EOF)
							{
								errlog(LOG_ERROR, "%s: EOF inside literal\n",
										current_file);
								BEGIN(INITIAL);
								break;
							}
							if (c == '\'')
							{
								*cp++ = c;
								*cp++ = c;
								len+=2;
								continue;
							}
							unput(c);
							*cp = '\0';
							BEGIN(INITIAL);
							return T_LITERAL;
						}
						*cp++ = c;
						len++;
					}
					*cp = '\0';
					return T_LITERAL_PART;
				}
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 223 "scan.l"
{
					char	   *cp = yychunk;
					size_t 		len = 0;
					int			c;
					bool		chunk_start;

					BEGIN(IN_STRING);

					chunk_start = true;
					while(len < sizeof(yychunk) - 1)
					{
						if (chunk_start)
						{
							c = *yytext;
							chunk_start = false;
						}
						else
						{
							c = input();
						}
						if (c == EOF)
						{
							errlog(LOG_ERROR, "%s: EOF inside literal\n",
									current_file);
							BEGIN(INITIAL);
							break;
						}
						if (c == '\\')
						{
							c = input();
							if (c == EOF)
							{
								errlog(LOG_ERROR, "%s: EOF inside literal\n",
										current_file);
								BEGIN(INITIAL);
								break;
							}
							*cp++ = c;
							*cp++ = c;
							len+=2;
							continue;
						}
						if (c == '\'')
						{
							c = input();
							if (c == EOF)
							{
								errlog(LOG_ERROR, "%s: EOF inside literal\n",
										current_file);
								BEGIN(INITIAL);
								break;
							}
							if (c == '\'')
							{
								*cp++ = c;
								*cp++ = c;
								len+=2;
								continue;
							}
							unput(c);
							*cp = '\0';
							BEGIN(INITIAL);
							return T_LITERAL;
						}
						*cp++ = c;
						len++;
					}
					*cp = '\0';
					return T_LITERAL_PART;
				}
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 294 "scan.l"
{
					BEGIN(COPYLS);
				}
	YY_BREAK
case 59:
/* rule 59 can match eol */
YY_RULE_SETUP
#line 297 "scan.l"
{
					BEGIN(INITIAL);
					return T_COPYEND;
				}
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 301 "scan.l"
{
					BEGIN(INITIAL);
					return T_COPYEND;
				}
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 305 "scan.l"
{
					char	   *cp = yychunk;
					size_t	   	len = 0;
					int			c;
					bool		chunk_start;

					BEGIN(COPY);

					chunk_start = true;
					while(len < sizeof(yychunk) - 2)
					{
						if (chunk_start)
						{
							c = yytext[0];
							chunk_start = false;
						}
						else
						{
							c = input();
						}
						if (c == EOF)
						{
							errlog(LOG_ERROR, "%s: EOF inside of COPY data\n",
									current_file);
							BEGIN(INITIAL);
							return T_COPYEND;
						}
						*cp++ = c;
						len++;
						if (c == '\n')
						{
							*cp = '\0';
							BEGIN(COPYLS);
							return T_COPYDATA;
						}
						if (len == 5)
						{
							*cp = '\0';
							return T_COPYDATA_PART;
						}
					}
					*cp = '\0';
					return T_COPYDATA_PART;
				}
	YY_BREAK
case 62:
/* rule 62 can match eol */
YY_RULE_SETUP
#line 350 "scan.l"
{
					char	   *cp = yychunk;
					size_t			len = 0;
					int			c;
					bool		chunk_start;

					chunk_start = true;
					while(len < sizeof(yychunk) - 2)
					{
						if (chunk_start)
						{
							c = yytext[0];
							chunk_start = false;
						}
						else
						{
							c = input();
						}
						if (c == EOF)
						{
							errlog(LOG_ERROR, "%s: EOF inside of COPY data\n",
									current_file);
							BEGIN(INITIAL);
							return T_COPYEND;
						}
						*cp++ = c;
						len++;
						if (c == '\n')
						{
							*cp = '\0';
							BEGIN(COPYLS);
							return T_COPYDATA;
						}
						if (len == 5)
						{
							*cp = '\0';
							return T_COPYDATA_PART;
						}
					}
					*cp = '\0';
					return T_COPYDATA_PART;
				}
	YY_BREAK
 /*
'		{ 
			start_charpos = yytext;
			BEGIN(IN_STRING);
		}
<IN_STRING>\\.	{ }
<IN_STRING>\\	{ }
<IN_STRING>''	{ }
<IN_STRING>'	{
			yyleng += (yytext - start_charpos) - 2;
			yytext = start_charpos + 1;
			BEGIN(INITIAL);
			return T_LITERAL;
		}
<IN_STRING>[^'\\]+ {}
*/

case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
#line 412 "scan.l"
{ addSymbol( yytext ); BEGIN(INITIAL); }
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 414 "scan.l"
{ 
                  char * value = getSymbol( yytext );
                  
                  if( value )
                  {
                    pushBuffer( strdup( current_file ));
                    yy_scan_string(value );
                  }
                }
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
#line 424 "scan.l"
{

                    char * fileName = strdup( yytext + 1 ); /* Skip '<' */

                    *strchr( fileName, '>' ) = '\0';        /* Trim '>' */

                    pushBuffer( fileName );

                    if(( yyin = fopen( fileName, "r" )) == NULL )
                    {
                        errlog(LOG_ERROR,  "Include file (%s) not found\n", fileName );
                        exit( 1 );
                    }
                 
                    yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE ));

                    BEGIN(INITIAL);
                }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(incl):
case YY_STATE_EOF(define):
case YY_STATE_EOF(IN_STRING):
case YY_STATE_EOF(COPYSTART):
case YY_STATE_EOF(COPY):
case YY_STATE_EOF(COPYLS):
#line 443 "scan.l"
{
                    if( yy_buffer == NULL )
					{
                        yyterminate();
						if (YY_CURRENT_BUFFER)
							yy_delete_buffer(YY_CURRENT_BUFFER);
					}
                    else
                        popBuffer();
                }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 454 "scan.l"
;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 456 "scan.l"
{ return yytext[0];				}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 458 "scan.l"
ECHO;
	YY_BREAK
#line 1843 "scan.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 391 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 391 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 390);

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 457 "scan.l"



void
scan_new_input_file(FILE *in)
{
	while (yy_buffer != NULL)
		popBuffer();

	if (YY_CURRENT_BUFFER)
		yy_delete_buffer(YY_CURRENT_BUFFER);

	yy_switch_to_buffer(yy_create_buffer(in,YY_BUF_SIZE));

	yylineno = 1;

    freeSymbols();
}

void scan_push_string(char *str)
{
	pushBuffer(strdup("init"));
	yy_scan_string (str);
}


int scan_yyinput(void)
{
	return input();
}

void scan_copy_start(void)
{
	BEGIN(COPYSTART);
}

void pushBuffer( char * context )
{
	struct __yy_buffer * yb = malloc( sizeof( *yb ));

	yb->buffer   = YY_CURRENT_BUFFER;
	yb->lineno   = yylineno;
	yb->fileName = current_file;
	yb->yyin	 = yyin;
	yb->prev     = yy_buffer;

	yy_buffer = yb;

	current_file = context;
	yylineno     = 1;
	yyin         = NULL;
}

static void popBuffer( void )
{
	struct __yy_buffer * yb = yy_buffer;

	if( yyin != NULL )
		fclose( yyin );
	
	yy_delete_buffer(YY_CURRENT_BUFFER );
	yy_switch_to_buffer(yy_buffer->buffer );
	
	current_file = yy_buffer->fileName;
	yylineno     = yy_buffer->lineno;
	yyin         = yy_buffer->yyin;
	
	yy_buffer = yy_buffer->prev;
	
	free( yb );
}

static void addSymbol( char * str )
{
	char   * name  = str;
	char   * value = str;
	symbol * sym   = NULL;

	while( *value != ' ' && *value != '\t' )
		value++;

	*(value++) = '\0';

	while( *value == ' ' || *value == '\t' )
		value++;

	value[strlen(value) - 1 ] = '\0';

	sym = malloc( sizeof( *sym ));
	sym->value = strdup( value );
	sym->next  = NULL;
	
	/* Store the symbol name in searchable form  with a leading @ */

	sym->name  = malloc( strlen( name ) + 1 + 1 );

	sym->name[0] = '@';
	strcpy( sym->name+1, name );

	if( symbols != NULL )
		sym->next = symbols;

	symbols = sym;
}

static char * getSymbol( const char * name )
{
	symbol * sym;

	for( sym = symbols; sym; sym = sym->next )
	{
		if( strcmp( name, sym->name ) == 0 )
			return( sym->value );
	}

	return( NULL );
}

static void freeSymbols( void )
{
	symbol * sym = symbols;

	while( sym )
	{
		symbol * victim = sym;

		sym = sym->next;

		free( victim->name );
		free( victim->value );
		free( victim );
	}

	symbols = NULL;
}
/*
 * Local Variables:
 *  tab-width: 4
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 */

